import winston from 'winston';
declare type LoggerArgs = any[];
export declare type Logger = winston.Logger & Record<'error' | 'warn' | 'info' | 'verbose' | 'debug' | 'silly' | 'log', (...args: LoggerArgs) => winston.Logger>;
export declare type LoggerFactory = {
    getLogger: (category: string) => Logger;
    logErrorsOnly: () => void;
};
declare type LoggerConfig = {
    /**
     * path to manager's logging.conf file
     */
    logLevelConf?: string;
    /**
     * default log level to be used when `logLevelConf` is not set, file defined by
     * `logLevelConf` does not exist, or the file exists but contains no entry for the given `serviceName`
     */
    logLevel?: string;
    /**
     * path to main log file
     */
    logsFile?: string;
    /**
     * path to errors log file
     */
    errorsFile?: string;
    /**
     * service name to look for in file specified by `logLevelConf`
     */
    serviceName?: string;
};
/**
 * Initializes logging framework according to the given config
 *
 * @param {LoggerConfig} config configuration object
 * @param {number} defaultMaxListeners optional number of default event listeners to be assigned to
 * EventEmitter.defaultMaxListeners, should be set to at least the number of logging categories to be used, defaults to 30
 *
 * @returns {LoggerFactory} object containing `getLogger` and `logErrorsOnly` functions
 */
declare function initLogging(config: LoggerConfig, defaultMaxListeners?: number): LoggerFactory;
export default initLogging;
//# sourceMappingURL=logger.d.ts.map