"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// ***********************************************************
// This example plugins/index.js can be used to load plugins
//
// You can change the location of this file or turn off loading
// the plugins file with the 'pluginsFile' configuration option.
//
// You can read more here:
// https://on.cypress.io/plugins-guide
// ***********************************************************
const task_1 = __importDefault(require("@cypress/code-coverage/task"));
const webpack_dev_server_1 = require("@cypress/webpack-dev-server");
const setRemovingVideosForPassedTestsTask_1 = __importDefault(require("./setRemovingVideosForPassedTestsTask"));
/**
 * Performs common plugin and configuration setup - registers coverage plugin and sets `baseUrl` property if MANAGER_IP
 * environment variable is set
 *
 * @param on Adds listener function to the end of the listeners array for the given event
 *           @see https://nodejs.org/api/events.html#events_emitter_on_eventname_listener
 *           @see https://docs.cypress.io/api/events/catalog-of-events.html#App-Events
 * @param config Cypress configuration object to be updated
 * @param webpackConfig Webpack configuration
 * @returns Updated configuration
 */
const setupPluginsAndConfig = (on, config, webpackConfig) => {
    (0, task_1.default)(on, config);
    const { MANAGER_IP, MANAGER_PROTOCOL = 'http' } = process.env;
    if (MANAGER_IP) {
        config.baseUrl = `${MANAGER_PROTOCOL}://${MANAGER_IP}`;
    }
    // eslint-disable-next-line no-console
    console.info(`Testing on: ${config.baseUrl}`);
    if (config.testingType === 'component') {
        on('dev-server:start', options => (0, webpack_dev_server_1.startDevServer)({
            options,
            webpackConfig
        }));
    }
    (0, setRemovingVideosForPassedTestsTask_1.default)(on);
    return config;
};
exports.default = setupPluginsAndConfig;
//# sourceMappingURL=index.js.map